# Overview

This repository includes Dash components for [Glue42](https://glue42.com) initialization and two way message exchange for Glue42 Channels, Shared Contexts, registering and invoking Interop methods.

# Documentation

For more information on how to use the Glue42 Dash library, see the [official documentation](https://docs.glue42.com/getting-started/how-to/glue42-enable-your-app/dash/index.html).

# Demos

Demo examples demonstrating the Glue42 Dash library are available in [this repo](https://github.com/Glue42/glue-dash-example).
